@@ -11,11 +11,12 @@ use File::Spec::Functions qw/catfile/;
 use Pod::Usage;
 use Text::Amuse::Compile::Utils qw/append_file/;
 use Text::Amuse::Compile::TemplateOptions;
+use Text::Amuse::Compile::Templates;
 use Text::Amuse::Compile::Fonts;
 use Encode;
 
-binmode STDOUT, ':encoding(utf-8)';
-binmode STDERR, ':encoding(utf-8)';
+binmode STDOUT, ':encoding(UTF-8)';
+binmode STDERR, ':encoding(UTF-8)';
 
 my %options;
 GetOptions (\%options,
@@ -349,9 +350,10 @@ if ($logfile) {
 print $compiler->version;
 
 if ($output_templates) {
-    my $viewdir = $compiler->templates->ttdir;
+    my $viewdir = $compiler->ttdir;
+    my $templates = Text::Amuse::Compile::Templates->new(ttdir => $viewdir);
     if (defined $viewdir) {
-        foreach my $template ($compiler->templates->names) {
+        foreach my $template ($templates->names) {
             my $target = catfile($viewdir, $template . '.tt');
             if (-f $target) {
                 warn "Refusing to overwrite $target\n";
@@ -360,7 +362,7 @@ if ($output_templates) {
                 warn "Creating $target\n";
                 open (my $fh, '>:encoding(utf-8)', $target)
                   or die "Couldn't open $target $!";
-                print $fh ${ $compiler->templates->$template };
+                print $fh ${ $templates->$template };
                 close $fh or die "Couldn't close $target $!";
             }
         }
